summaryrefslogtreecommitdiffstats
path: root/src/Simulator/Simulator.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/Simulator/Simulator.h')
-rw-r--r--src/Simulator/Simulator.h5
1 files changed, 4 insertions, 1 deletions
diff --git a/src/Simulator/Simulator.h b/src/Simulator/Simulator.h
index e18465bee..32a36213b 100644
--- a/src/Simulator/Simulator.h
+++ b/src/Simulator/Simulator.h
@@ -27,7 +27,7 @@ public:
virtual ~cSimulator() {}
// Contains our direct adjacents
static constexpr std::array<Vector3i, 6> AdjacentOffsets
{
{
@@ -40,6 +40,9 @@ public:
}
};
+ /** For a given offset from a position, return the offsets that represent the adjacents of the newly offset position, excluding the old position. */
+ static std::array<Vector3i, 5> GetLinkedOffsets(Vector3i Offset);
+
protected:
friend class cChunk; // Calls AddBlock() in its WakeUpSimulators() function, to speed things up
@@ -27,7 +27,7 @@ public:
virtual ~cSimulator() {}
- // Contains our direct adjacents
+ /** Contains offsets for direct adjacents of any position. */
static constexpr std::array<Vector3i, 6> AdjacentOffsets
{